@@ -2,6 +2,11 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendář",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdálený server nepovolil přístup ke kalendáři (HTTP {%s} chyba)",
+    "Error connecting to remote server" : "Chyba připojování ke vzdálenému serveru",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Chyba při vyžádání zdroje na vzdáleném serveru. To může být způsobeno neshodným certifikátem",
+    "Error requesting resource on remote server" : "Chyba při vyžádání zdroje na vzdáleném serveru",
+    "%s has published the calendar \"%s\"" : "%s publikoval kalendář \"%s\"",
     "Individual" : "Individuální",
     "Group" : "Skupina",
     "Resource" : "Zdroj",
@@ -13,6 +18,13 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Nacházíte se v neznámé časové zóně ({tz}), použije se UTC",
     "Please create a calendar first." : "Nejdříve prosím vytvořte kalendář.",
     "New event" : "Nová událost",
+    "CalDAV address for clients" : "CalDAV adresa pro klientské aplikace",
+    "Error saving WebCal-calendar" : "Chyba při ukládání WebCal kalendáře",
+    "WebDAV address for subscriptions" : "WebDAV adresa pro odběry",
+    "EMail has been sent." : "Email byl odeslán.",
+    "There was an issue while sending your EMail." : "Došlo k problému v průběhu odesílání emailu.",
+    "group" : "skupina",
+    "Details" : "Podrobnosti",
     "Attendees" : "Účastníci",
     "Reminders" : "Připomínky",
     "Repeating" : "Opakování",
@@ -67,6 +79,8 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} při konci události",
     "{type} at {time}" : "{type} v {time}",
     "{calendar} shared by {owner}" : "{calendar} sdílen uživatelem {owner}",
+    "Please enter a valid WebCal-URL" : "Zadejte prosím platnout WebCal URL",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Kritická chyba ve webcal proxy. Pro více informací kontaktujte svého administrátora.",
     "Title of the Event" : "Název události",
     "starts" : "začíná",
     "ends" : "končí",
@@ -82,6 +96,13 @@ OC.L10N.register(
     "Event status" : "Stav události",
     "Visibility when sharing" : "Viditelnost při sdílení",
     "Export" : "Exportovat",
+    "%s has published the calendar %s" : "%s zveřejnil kalendář %s",
+    "Hello," : "Ahoj,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chtěli jsme vás informovat, že %s zveřejnil kalendář {boldstart}%s{boldend}.",
+    "Click here to access it" : "Pro přístup klikněte zde",
+    "Cheers!" : "Mějte se!",
+    "We wanted to inform you that %s has published the calendar %s." : "Chtěli jsme vás informovat, že %s zveřejnil kalendář %s.",
+    "Click on the link below to access it" : "Pro přístup klikněte na odkaz níže",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Kalendář v současné chvíli nemůže nabídnout podporu pro funkci \"asset pipeline\" (spojení a komprese css a js souborů).",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontaktujte prosím svého administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
     "Day" : "Den",
@@ -94,14 +115,20 @@ OC.L10N.register(
     "More" : "Více",
     "Edit" : "Upravit",
     "Link" : "Odkaz",
+    "WebCal URL" : "WebCal URL",
     "Download" : "Stáhnout",
     "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
     "can edit" : "lze upravovat",
-    "group" : "skupina",
+    "Share link" : "Sdílet odkaz",
+    "Public access" : "Veřejný přístup",
+    "Email link to person" : "Odeslat odkaz emailem",
+    "Send" : "Odeslat",
     "New Calendar" : "Nový kalendář",
-    "Subscriptions" : "Odběry",
+    "Name" : "Název",
     "New Subscription" : "Nový odběr",
-    "Url" : "URL",
+    "WebCal-URL" : "WebCal-URL",
+    "Go back" : "Jít zpět",
+    "Go forward" : "Jít vpřed",
     "Edit event" : "Upravit událost",
     "Delete Event" : "Smazat událost",
     "Save Event" : "Uložit událost",
@@ -129,7 +156,10 @@ OC.L10N.register(
     "New calendar" : "Nový kalendář",
     "Import scheduled" : "Import načasován",
     "Settings" : "Nastavení",
+    "Publish URL" : "Zveřejnit URL",
+    "Iframe to integrate" : "Iframe k integraci",
     "Skip simple event editor" : "Přeskočit jednoduchý editor události",
+    "Show week numbers" : "Zobrazit čísla týdnů",
     "Import calendar" : "Importovat kalendář",
     "No Calendars selected for import" : "Nebyl vybrán kalendář k importu",
     "Primary CalDAV address" : "Primární adresa CalDAV",
