@@ -13,6 +13,7 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "You are in an unknown timezone ({tz}), falling back to UTC",
     "Please create a calendar first." : "Please create a calendar first.",
     "New event" : "New event",
+    "group" : "group",
     "Attendees" : "Attendees",
     "Reminders" : "Reminders",
     "Repeating" : "Repeating",
@@ -97,11 +98,9 @@ OC.L10N.register(
     "Download" : "Download",
     "Share with users or groups" : "Share with users or groups",
     "can edit" : "can edit",
-    "group" : "group",
     "New Calendar" : "New Calendar",
-    "Subscriptions" : "Subscriptions",
+    "Name" : "Name",
     "New Subscription" : "New Subscription",
-    "Url" : "URL",
     "Edit event" : "Edit event",
     "Delete Event" : "Delete Event",
     "Save Event" : "Save Event",
