@@ -2,6 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
+    "%s has published the calendar \"%s\"" : "%s ha publicado el calendario \"%s\"",
     "Individual" : "Individual",
     "Group" : "Grupo",
     "Resource" : "Recurso",
@@ -10,9 +11,16 @@ OC.L10N.register(
     "Required" : "Requerido",
     "Optional" : "Opcional",
     "Does not attend" : "No asistir",
-    "You are in an unknown timezone ({tz}), falling back to UTC" : "Estás en una zona horaria desconocida ({tz}), volviendo a  UTC",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está en una zona horaria desconocida ({tz}), volviendo a UTC",
     "Please create a calendar first." : "Por favor, cree primero un calendario.",
     "New event" : "Nuevo evento",
+    "CalDAV address for clients" : "Dirección CalDAV para los clientes",
+    "Error saving WebCal-calendar" : "Error salvando Calendario-WebCal",
+    "WebDAV address for subscriptions" : "Dirección WebDAV para los subscriptores",
+    "EMail has been sent." : "El correo electrónico ha sido envidado.",
+    "There was an issue while sending your EMail." : "Ha habido un problema en el envío de su correo electrónico.",
+    "group" : "grupo",
+    "Details" : "Detalles",
     "Attendees" : "Asistentes",
     "Reminders" : "Recordatorios",
     "Repeating" : "Repetición",
@@ -51,7 +59,7 @@ OC.L10N.register(
     "before" : "antes",
     "start" : "comienzo",
     "end" : "fin",
-    "Editing reminders of unknown type not supported." : "No esta soportado el editar recordatorios de tipo desconocido.",
+    "Editing reminders of unknown type not supported." : "La edición de recordatorios de tipo desconocido no tiene respaldo.",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Successfully imported" : "Importado exitosamente",
     "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
@@ -67,6 +75,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} al final del evento",
     "{type} at {time}" : "{type} a {time}",
     "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
+    "Please enter a valid WebCal-URL" : "Por favor introduzca una URL valida WebCal",
     "Title of the Event" : "Título del evento",
     "starts" : "comienza",
     "ends" : "finaliza",
@@ -82,6 +91,11 @@ OC.L10N.register(
     "Event status" : "Estado del evento",
     "Visibility when sharing" : "Visibilidad cuando se comparte",
     "Export" : "Exportar",
+    "%s has published the calendar %s" : "%s ha publicado el calendario %s",
+    "Hello," : "Hola.",
+    "Click here to access it" : "Pincha aquí para obtener acceso a esto",
+    "Cheers!" : "¡Saludos!",
+    "Click on the link below to access it" : "Pincha en el enlace de abajo para tener acceso a esto",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Debido a un bug de upstream, el calendario no soporta la funcionalidad de asset pipeline",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor contacta con el administrador y proponle que desactive la opción \"asset-pipeline.enabled'.",
     "Day" : "Día",
@@ -94,14 +108,19 @@ OC.L10N.register(
     "More" : "Más",
     "Edit" : "Editar",
     "Link" : "Enlace",
+    "WebCal URL" : "WebCal URL",
     "Download" : "Descargar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "can edit" : "puede editar",
-    "group" : "grupo",
+    "Share link" : "Enlace compartido",
+    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
+    "Send" : "Enviar",
     "New Calendar" : "Nuevo calendario",
-    "Subscriptions" : "Suscripciones",
+    "Name" : "Nombre",
     "New Subscription" : "Nueva suscripción",
-    "Url" : "Url",
+    "WebCal-URL" : "WebCal-URL",
+    "Go back" : "Atrás",
+    "Go forward" : "Adelante",
     "Edit event" : "Editar evento",
     "Delete Event" : "Eliminar evento",
     "Save Event" : "Guardar evento",
@@ -129,7 +148,9 @@ OC.L10N.register(
     "New calendar" : "Nuevo calendario",
     "Import scheduled" : "Importar horario",
     "Settings" : "Ajustes",
+    "Publish URL" : "Publicar URL",
     "Skip simple event editor" : "Omitir el editor de evento único",
+    "Show week numbers" : "Mostrar numero de semana",
     "Import calendar" : "Importar calendario",
     "No Calendars selected for import" : "No se seleccionó un calendario para importar",
     "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
