@@ -2,6 +2,9 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Agenda",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ce serveur distant ne semble pas nous donner accès au calendrier (erreur HTTP {%s})",
+    "Error connecting to remote server" : "Erreur de connexion au serveur distant",
+    "%s has published the calendar \"%s\"" : "%s a publié le calendrier \"%s\"",
     "Individual" : "Individuel",
     "Group" : "Groupe",
     "Resource" : "Ressource",
@@ -13,6 +16,13 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Vous êtes dans un fuseau horaire inconnu ({tz}), retour à UTC",
     "Please create a calendar first." : "Veuillez d'abord créer un calendrier.",
     "New event" : "Nouvel événement",
+    "CalDAV address for clients" : "Adresse CalDAV pour les clients",
+    "Error saving WebCal-calendar" : "Erreur de sauvegarde du calendrier WebCal",
+    "WebDAV address for subscriptions" : "Adresse WebDAV pour s'inscrire",
+    "EMail has been sent." : "L'EMail a été envoyé.",
+    "There was an issue while sending your EMail." : "Il y a eu un problème lors de l'envoi de votre EMail.",
+    "group" : "groupe",
+    "Details" : "Détails",
     "Attendees" : "Participants",
     "Reminders" : "Rappels",
     "Repeating" : "Occurrences",
@@ -67,6 +77,8 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} à la fin de l'événement",
     "{type} at {time}" : "{type} à {time}",
     "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
+    "Please enter a valid WebCal-URL" : "Veuillez saisir une URL WebCal valide",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Erreur grave du mandataire webcal.  Communiquez avec votre administrateur de réseau pour plus de renseignements.",
     "Title of the Event" : "Titre de l'événement",
     "starts" : "démarre",
     "ends" : "termine",
@@ -82,6 +94,13 @@ OC.L10N.register(
     "Event status" : "Statut de l'événement",
     "Visibility when sharing" : "Visibilité pendant le partage",
     "Export" : "Exporter",
+    "%s has published the calendar %s" : "%s a publié l'agenda %s",
+    "Hello," : "Bonjour,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Nous voulions vous informer que %s a publié l'agenda {boldstart}%s{boldend}.",
+    "Click here to access it" : "Cliquez ici pour y accéder",
+    "Cheers!" : "À bientôt !",
+    "We wanted to inform you that %s has published the calendar %s." : "Nous voulions vous informer que %s a publié l'agenda %s.",
+    "Click on the link below to access it" : "Cliquez sur le lien ci-dessous pour y accéder",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A cause d'un bug en amont, le calendrier ne peut actuellement pas prendre en charge la fonction de pipeline d'actifs.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Veuillez contacter votre administrateur afin de lui demander de désactiver l'option de configuration \"asset-pipeline.enabled\".",
     "Day" : "Jour",
@@ -94,14 +113,20 @@ OC.L10N.register(
     "More" : "Plus",
     "Edit" : "Éditer",
     "Link" : "Lien",
+    "WebCal URL" : "URL WebCal",
     "Download" : "Télécharger",
     "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
     "can edit" : "peut modifier",
-    "group" : "groupe",
+    "Share link" : "Partager un lien",
+    "Public access" : "Accès public",
+    "Email link to person" : "Envoyer un lien par courriel",
+    "Send" : "Envoyer",
     "New Calendar" : "Nouvel agenda",
-    "Subscriptions" : "Abonnements",
+    "Name" : "Nom",
     "New Subscription" : "Nouvel abonnement",
-    "Url" : "URL",
+    "WebCal-URL" : "URL WebCal",
+    "Go back" : "Aller au précédent",
+    "Go forward" : "Aller au suivant",
     "Edit event" : "Modifier l'événement",
     "Delete Event" : "Supprimer l'événement",
     "Save Event" : "Enregistrer l'événement",
@@ -119,8 +144,8 @@ OC.L10N.register(
     "This event's repeating rule is not supported yet." : "La répétition de cet évènement n'est pas prise en charge pour le moment.",
     "Support for advanced rules will be added with subsequent updates." : "Le support de règles multiples sera ajouté dans des mises à jour ultérieures.",
     "Reset repeating rule" : "Réinitialiser la règle de répétition",
-    "Repeat every ..." : "Répéter tous les ...",
-    "end repeat ..." : "Arrêter la répétition ...",
+    "Repeat every ..." : "Répéter tous les…",
+    "end repeat ..." : "arrêter la répétition…",
     "times" : "fois",
     "Import Calendars" : "Importer des agendas",
     "Import canceled" : "Importation annulée",
@@ -129,6 +154,10 @@ OC.L10N.register(
     "New calendar" : "Nouvel agenda",
     "Import scheduled" : "Importation planifiée",
     "Settings" : "Paramètres",
+    "Publish URL" : "Publier l'URL",
+    "Iframe to integrate" : "Iframe à intégrer",
+    "Skip simple event editor" : "Passer l'éditeur d'évènement simple",
+    "Show week numbers" : "Afficher les numéros de semaine",
     "Import calendar" : "Importer un agenda",
     "No Calendars selected for import" : "Aucun agenda sélectionné pour import",
     "Primary CalDAV address" : "Adresse CalDAV principale",
