@@ -13,6 +13,8 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "הנך באזור זמן לא ידוע ({tz}), מעביר חזרה לאזור זמן UTC",
     "Please create a calendar first." : "יש ליצור לוח שנה תחילה.",
     "New event" : "אירוע חדש",
+    "Error saving WebCal-calendar" : "שגיאה בשמירת WebCal-calendar",
+    "group" : "קבוצה",
     "Attendees" : "משתתפים",
     "Reminders" : "תזכורות",
     "Repeating" : "חוזר",
@@ -67,6 +69,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} בסיום האירוע",
     "{type} at {time}" : "{type} בשעה {time}",
     "{calendar} shared by {owner}" : "{calendar} משותף על ידי {owner}",
+    "Please enter a valid WebCal-URL" : "יש להכניס נתיב אינטרנט WebCal חוקי",
     "Title of the Event" : "כותרת האירוע",
     "starts" : "מתחיל",
     "ends" : "מסתיים",
@@ -94,14 +97,14 @@ OC.L10N.register(
     "More" : "יותר",
     "Edit" : "עריכה",
     "Link" : "קישור",
+    "WebCal URL" : "נתיב אינטרנט WebCal",
     "Download" : "הורדה",
     "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
     "can edit" : "ניתן לערוך",
-    "group" : "קבוצה",
     "New Calendar" : "לוח שנה חדש",
-    "Subscriptions" : "מנויים",
+    "Name" : "שם",
     "New Subscription" : "מנוי חדש",
-    "Url" : "נתיב אינטרנט",
+    "WebCal-URL" : "נתיב אינטרנט WebCal",
     "Edit event" : "ערוך אירוע",
     "Delete Event" : "מחיקת אירוע",
     "Save Event" : "שמירת אירוע",
@@ -130,6 +133,7 @@ OC.L10N.register(
     "Import scheduled" : "לוח זמנים ליבוא",
     "Settings" : "הגדרות",
     "Skip simple event editor" : "מדלג על עורך אירוע פשוט",
+    "Show week numbers" : "הצגת מספרי שבועות",
     "Import calendar" : "יבוא יומן",
     "No Calendars selected for import" : "לא נבחרו יומנים ליבוא",
     "Primary CalDAV address" : "כתובת CalDAV ראשית",
