@@ -2,6 +2,11 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Il server remoto ha negato l'accesso al calendario (errore HTTP {%s})",
+    "Error connecting to remote server" : "Errore durante la connessione al server remoto",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Errore durante la richiesta di una risorsa al server remoto. Ciò potrebbe essere dovuto da una mancata corrispondenza del certificato",
+    "Error requesting resource on remote server" : "Errore durante la richiesta di una risorsa al server remoto",
+    "%s has published the calendar \"%s\"" : "%s ha pubblicato il calendario \"%s\"",
     "Individual" : "Singolo",
     "Group" : "Gruppo",
     "Resource" : "Risorsa",
@@ -13,6 +18,13 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Sei in un fuso orario sconosciuto ({tz}), ripiego su UTC",
     "Please create a calendar first." : "Crea prima un calendario.",
     "New event" : "Nuovo evento",
+    "CalDAV address for clients" : "Indirizzo CalDAV per i client",
+    "Error saving WebCal-calendar" : "Errore durante il salvataggio del calendario WebCal",
+    "WebDAV address for subscriptions" : "Indirizzo WebDAV per le sottoscrizioni",
+    "EMail has been sent." : "L'email è stata inviata.",
+    "There was an issue while sending your EMail." : "C'è stato un problema durante l'invio della tua email.",
+    "group" : "gruppo",
+    "Details" : "Dettagli",
     "Attendees" : "Partecipanti",
     "Reminders" : "Promemoria",
     "Repeating" : "Ripetizione",
@@ -21,7 +33,7 @@ OC.L10N.register(
     "When shared hide this event" : "Se condiviso, nascondi questo evento",
     "Confirmed" : "Confermato",
     "Tentative" : "Provvisorio",
-    "Cancelled" : "Annullati",
+    "Cancelled" : "Annullato",
     "Please add a title!" : "Aggiungi un titolo!",
     "Please select a calendar!" : "Seleziona un calendario!",
     "Global" : "Globale",
@@ -67,6 +79,8 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} alla fine dell'evento",
     "{type} at {time}" : "{type} alle {time}",
     "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
+    "Please enter a valid WebCal-URL" : "Digita un URL WebCal valido",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Errore grave nel proxy webcal. Contatta l'amministratore per ulteriori informazioni.",
     "Title of the Event" : "Titolo dell'evento",
     "starts" : "inizia",
     "ends" : "finisce",
@@ -82,6 +96,13 @@ OC.L10N.register(
     "Event status" : "Stato dell'evento",
     "Visibility when sharing" : "Visibilità in caso di condivisione",
     "Export" : "Esporta",
+    "%s has published the calendar %s" : "%s ha pubblicato il calendario %s",
+    "Hello," : "Ciao,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Ti vogliamo informare che %s ha pubblicato il calendario {boldstart}%s{boldend}.",
+    "Click here to access it" : "Fai clic qui per accedere",
+    "Cheers!" : "Evviva!",
+    "We wanted to inform you that %s has published the calendar %s." : "Ti vogliamo informare che %s ha pubblicato il calendario %s.",
+    "Click on the link below to access it" : "Fai clic sul collegamento sotto per accedere",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contatta il tuo amministratore e chiedigli di disabilitare l'opzione di configurazione \"asset-pipeline.enabled\".",
     "Day" : "Giorno",
@@ -94,14 +115,20 @@ OC.L10N.register(
     "More" : "Altro",
     "Edit" : "Modifica",
     "Link" : "Collegamento",
+    "WebCal URL" : "URL WebCal",
     "Download" : "Scarica",
     "Share with users or groups" : "Condividi con utenti o gruppi",
     "can edit" : "può modificare",
-    "group" : "gruppo",
+    "Share link" : "Condividi il collegamento",
+    "Public access" : "Accesso pubblico",
+    "Email link to person" : "Invia il collegamento alla persona tramite email",
+    "Send" : "Invia",
     "New Calendar" : "Nuovo calendario",
-    "Subscriptions" : "Sottoscrizioni",
+    "Name" : "Nome",
     "New Subscription" : "Nuova sottoscrizione",
-    "Url" : "URL",
+    "WebCal-URL" : "URL WebCal",
+    "Go back" : "Indietro",
+    "Go forward" : "Avanti",
     "Edit event" : "Modifica evento",
     "Delete Event" : "Elimina evento",
     "Save Event" : "Salva evento",
@@ -129,7 +156,10 @@ OC.L10N.register(
     "New calendar" : "Nuovo calendario",
     "Import scheduled" : "Importa pianificati",
     "Settings" : "Impostazioni",
+    "Publish URL" : "Pubblica URL",
+    "Iframe to integrate" : "Iframe da integrare",
     "Skip simple event editor" : "Salta l'editor semplice degli eventi",
+    "Show week numbers" : "Mostra i numeri delle settimane",
     "Import calendar" : "Importa calendario",
     "No Calendars selected for import" : "Nessun calendario selezionato per l'importazione",
     "Primary CalDAV address" : "Indirizzo CalDAV principale",
