@@ -10,6 +10,8 @@ OC.L10N.register(
     "Required" : "必須",
     "Optional" : "オプション",
     "Does not attend" : "出席しない",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "タイムゾーン ({tz})が不明です，UTCを代替にします｡",
+    "Please create a calendar first." : "初めにカレンダーを作成してください",
     "New event" : "新しいイベント",
     "Attendees" : "参加者",
     "Reminders" : "リマインダー",
@@ -86,9 +88,8 @@ OC.L10N.register(
     "can edit" : "編集を許可",
     "group" : "グループ",
     "New Calendar" : "新しいカレンダーを作成",
-    "Subscriptions" : "購読",
+    "Name" : "名前",
     "New Subscription" : "新しい購読",
-    "Url" : "Url",
     "Edit event" : "イベントを編集",
     "Delete Event" : "イベントを削除",
     "Save Event" : "イベントを保存",
@@ -99,9 +100,11 @@ OC.L10N.register(
     "Repeat" : "繰り返し",
     "times every" : "繰り返し",
     "Add" : "追加",
+    "E-Mail address of attendee" : "参加者のメールアドレス",
     "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
     "from" : "差出人",
     "to" : "宛先",
+    "This event's repeating rule is not supported yet." : "イベントの繰り返しルールはまだサポートされていません。",
     "Reset repeating rule" : "繰り返し規則のリセット",
     "Repeat every ..." : "繰り返し…",
     "Import Calendars" : "カレンダーのインポート",
@@ -111,6 +114,7 @@ OC.L10N.register(
     "New calendar" : "新しいカレンダー",
     "Import scheduled" : "スケジュールのインポート",
     "Settings" : "設定",
+    "Skip simple event editor" : "シンプルイベントエディタをスキップ",
     "Import calendar" : "カレンダーのインポート",
     "No Calendars selected for import" : "インポートするカレンダーが指定されていません",
     "Primary CalDAV address" : "一番目の CalDAV アドレス",
