@@ -2,6 +2,11 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "De externe server verleende geen toegang tot de agenda (HTTP {%s} fout)",
+    "Error connecting to remote server" : "Fout bij het verbinden met de externe server",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fout bij opvragen object op externe server. Dit kan te maken hebben met een onjuist certificaat",
+    "Error requesting resource on remote server" : "Fout bij opvragen object op externe server.",
+    "%s has published the calendar \"%s\"" : "%s publiceerde agenda \"%s\"",
     "Individual" : "Individueel",
     "Group" : "Groep",
     "Resource" : "Bron",
@@ -13,6 +18,13 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "U bevindt zich in een onbekende tijdzone ({tz}), UTC zal worden gebruikt",
     "Please create a calendar first." : "Maak eerst een kalender aan",
     "New event" : "Nieuwe afspraak",
+    "CalDAV address for clients" : "CalDAV adres voor clients",
+    "Error saving WebCal-calendar" : "Fout bij opslaan WebCal agenda",
+    "WebDAV address for subscriptions" : "WebDAV adres voor abonnementen",
+    "EMail has been sent." : "E-mail is verstuurd",
+    "There was an issue while sending your EMail." : "Er was een probleem bij het versturen van je e-mailbericht.",
+    "group" : "groep",
+    "Details" : "Details",
     "Attendees" : "Deelnemers",
     "Reminders" : "Herinneringen",
     "Repeating" : "Herhaling",
@@ -67,6 +79,8 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} bij het eind van de afspraak",
     "{type} at {time}" : "{type} om {time}",
     "{calendar} shared by {owner}" : "{calendar} gedeeld door {owner}",
+    "Please enter a valid WebCal-URL" : "Voer een geldig WebCal-URL in",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Ernstige fout in webcal proxy. Neem contact op met de beheerder voor meer informatie.",
     "Title of the Event" : "Titel van de afspraak",
     "starts" : "begint",
     "ends" : "eindigt",
@@ -82,6 +96,13 @@ OC.L10N.register(
     "Event status" : "Afspraak status",
     "Visibility when sharing" : "Zichtbaarheid bij delen",
     "Export" : "Exporteer",
+    "%s has published the calendar %s" : "%s publiceerde agenda %s",
+    "Hello," : "Hallo,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "We willen je informeren dat %s agenda {boldstart}%s{boldend} heeft gepubliceerd.",
+    "Click here to access it" : "Klik hier om er te komen",
+    "Cheers!" : "Proficiat!",
+    "We wanted to inform you that %s has published the calendar %s." : "We willen je informeren dat %s agenda %s heeft gepubliceerd.",
+    "Click on the link below to access it" : "Klik op onderstaande link om er te komen",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Wegens een upstream bug kan de kalender nu de asset pipeline mogelijkheid niet ondersteunen.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Neem contact op met de beheerder en vraag om de configuratieoptie \"asset-pipeline.enabled\" uit te schakelen.",
     "Day" : "Dag",
@@ -94,14 +115,20 @@ OC.L10N.register(
     "More" : "Meer",
     "Edit" : "Bewerk",
     "Link" : "Link",
+    "WebCal URL" : "WebCal URL",
     "Download" : "Downloaden",
     "Share with users or groups" : "Delen met gebruikers of groepen",
     "can edit" : "kan wijzigen",
-    "group" : "groep",
+    "Share link" : "Delen link",
+    "Public access" : "Openbare toegang",
+    "Email link to person" : "E-mail link naar persoon",
+    "Send" : "Versturen",
     "New Calendar" : "Nieuwe agenda",
-    "Subscriptions" : "Abonnementen",
+    "Name" : "Naam",
     "New Subscription" : "Nieuw abonnement",
-    "Url" : "Url",
+    "WebCal-URL" : "WebCal-URL",
+    "Go back" : "Ga terug",
+    "Go forward" : "Ga verder",
     "Edit event" : "Bewerk gebeurtenis",
     "Delete Event" : "Verwijder afspraak",
     "Save Event" : "Bewaar afspraak",
@@ -129,6 +156,10 @@ OC.L10N.register(
     "New calendar" : "Nieuwe agenda",
     "Import scheduled" : "Import ingepland",
     "Settings" : "Instellingen",
+    "Publish URL" : "Publiceren URL",
+    "Iframe to integrate" : "Iframe om te integreren",
+    "Skip simple event editor" : "Negeer simpele afsprakenbewerker",
+    "Show week numbers" : "Tonen weeknummers",
     "Import calendar" : "Importeer agenda",
     "No Calendars selected for import" : "Geen agenda's voor import opgegeven",
     "Primary CalDAV address" : "Primair CalDAV adres",
