@@ -2,6 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendarz",
+    "%s has published the calendar \"%s\"" : "%s opublikował kalendarz \"%s\"",
     "Individual" : "Indywidualny",
     "Group" : "Grupa",
     "Resource" : "Źródło",
@@ -10,15 +11,24 @@ OC.L10N.register(
     "Required" : "Wymagany",
     "Optional" : "Opcjonalny",
     "Does not attend" : "Nie uczestniczy",
-    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracanie do UTC",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jesteś w nieznanej strefie czasowej ({tz}), powracam do UTC",
     "Please create a calendar first." : "Proszę najpierw stworzyć kalendarz.",
     "New event" : "Nowe zdarzenie",
+    "CalDAV address for clients" : "Adres CalDAV dla klientów",
+    "Error saving WebCal-calendar" : "Błąd podczas zapisywania kalendarza WebCal",
+    "WebDAV address for subscriptions" : "Adres WebDAV dla subskrypcji",
+    "EMail has been sent." : "Email został wysłany.",
+    "There was an issue while sending your EMail." : "Wystąpił problem podczas wysyłania e-maila.",
+    "group" : "grupa",
+    "Details" : "Szczegóły",
     "Attendees" : "Uczestnicy",
     "Reminders" : "Przypomnienia",
     "Repeating" : "Powtarzające się",
     "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
     "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
     "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
+    "Confirmed" : "Potwierdzone",
+    "Tentative" : "Możliwe",
     "Cancelled" : "Przerwano",
     "Please add a title!" : "Proszę dodać tytuł!",
     "Please select a calendar!" : "Proszę wybrać kalendarz!",
@@ -65,6 +75,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} na końcu wydarzenia",
     "{type} at {time}" : "{type} o {time}",
     "{calendar} shared by {owner}" : "{calendar} współdzielony przez {owner}",
+    "Please enter a valid WebCal-URL" : "Wprowadź prawidłowy URL WebCal",
     "Title of the Event" : "Nazwa wydarzenia",
     "starts" : "rozpoczyna się",
     "ends" : "kończy się",
@@ -77,26 +88,42 @@ OC.L10N.register(
     "Close" : "Zamknij",
     "Location" : "Lokalizacja",
     "Description" : "Opis",
+    "Event status" : "Status zdarzenia",
+    "Visibility when sharing" : "Widoczność podczas współdzielenia",
     "Export" : "Eksportuj",
+    "%s has published the calendar %s" : "%s opublikował kalendarz %s",
+    "Hello," : "Witaj,",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chcieliśmy poinformować, że %s opublikował kalendarz {boldstart}%s{boldend}.",
+    "Click here to access it" : "Kliknij tutaj, aby uzyskać dostęp do niego",
+    "Cheers!" : "Na zdrowie!",
+    "We wanted to inform you that %s has published the calendar %s." : "Chcieliśmy poinformować, że %s opublikował kalendarz %s.",
+    "Click on the link below to access it" : "Kliknij na link poniżej, aby uzyskać dostęp do niego",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Z powodu błędu w zewnętrznej bibliotece, kalendarz nie wspiera funkcji \"asset pipeline\".",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Skontaktuj się z administratorem i poproś o wyłączenie opcji \"asset-pipeline.enabled\"  w konfiguracji.",
     "Day" : "Dzień",
     "Week" : "Tydzień",
     "Month" : "Miesiąc",
     "Today" : "Dziś",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Niektóre zdarzenia w tym kalendarzu są uszkodzone. Proszę sprawdzić konsole JS aby dowiedzieć się więcej.",
     "Share Calendar" : "Współdziel kalendarz",
     "Shared" : "Udostępniono",
     "More" : "Więcej",
     "Edit" : "Edytuj",
     "Link" : "Link",
+    "WebCal URL" : "URL WebCal",
     "Download" : "Pobierz",
     "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
     "can edit" : "może edytować",
-    "group" : "grupa",
+    "Share link" : "Udostępnij link",
+    "Public access" : "Dostęp publiczny",
+    "Email link to person" : "Wyślij wiadomość do osoby",
+    "Send" : "Wysłać",
     "New Calendar" : "Nowy kalendarz",
-    "Subscriptions" : "Subskrypcje",
+    "Name" : "Nazwa",
     "New Subscription" : "Nowa Subskrypcja",
-    "Url" : "Url",
+    "WebCal-URL" : "URL-WebCal",
+    "Go back" : "Wróć",
+    "Go forward" : "Naprzód",
     "Edit event" : "Edytuj zdarzenie",
     "Delete Event" : "Usuń zdarzenie",
     "Save Event" : "Zapisz zdarzenie",
@@ -124,6 +151,10 @@ OC.L10N.register(
     "New calendar" : "Nowy kalendarz",
     "Import scheduled" : "Import został zaplanowany",
     "Settings" : "Ustawienia",
+    "Publish URL" : "Publikowanie URL",
+    "Iframe to integrate" : "Zintegrować z ramką",
+    "Skip simple event editor" : "Pomiń prosty edytor zdarzeń",
+    "Show week numbers" : "Pokaż numery tygodni",
     "Import calendar" : "Importuj kalendarz",
     "No Calendars selected for import" : "Nie wybrano kalendarzy do importu",
     "Primary CalDAV address" : "Podstawowy adres CalDAV",
