@@ -13,12 +13,16 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Está numa zona horária desconhecida ({tz}), a repor para UTC",
     "Please create a calendar first." : "Por favor, crie primeiro um calendário.",
     "New event" : "Novo evento",
+    "Error saving WebCal-calendar" : "Erro ao guardar o calendário WebCal",
+    "group" : "grupo",
     "Attendees" : "Participantes",
     "Reminders" : "Lembretes",
     "Repeating" : "Repetição",
     "When shared show full event" : "Quando partilhado, mostrar evento completo",
     "When shared show only busy" : "Quando partilhado, mostrar apenas ocupados",
     "When shared hide this event" : "Quando partilhado, ocultar este evento",
+    "Confirmed" : "Confirmado",
+    "Tentative" : "Tentativa",
     "Cancelled" : "Cancelado",
     "Please add a title!" : "Por favor, adicione um titulo!",
     "Please select a calendar!" : "Por favor, selecione um calendário!",
@@ -65,6 +69,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} no final do evento",
     "{type} at {time}" : "{type} às {time}",
     "{calendar} shared by {owner}" : "{calendar} partilhado por {owner}",
+    "Please enter a valid WebCal-URL" : "Por favor, introduza uma endereço WebCal válido",
     "Title of the Event" : "Título do Evento",
     "starts" : "começa",
     "ends" : "termina",
@@ -77,6 +82,7 @@ OC.L10N.register(
     "Close" : "Fechar",
     "Location" : "Localização:",
     "Description" : "Descrição",
+    "Event status" : "Estado do evento",
     "Export" : "Exportar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um erro próximo da fonte, o calendário atualmente não consegue dar suporte para a função de transporte do recurso.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor, contacte o seu administrador e peça-lhe para desativar a opção de configuração \"asset-pipeline.enabled\".",
@@ -89,14 +95,14 @@ OC.L10N.register(
     "More" : "Mais",
     "Edit" : "Editar",
     "Link" : "Hiperligação",
+    "WebCal URL" : "Endereço WebCal",
     "Download" : "Transferir",
     "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
     "can edit" : "pode editar",
-    "group" : "grupo",
     "New Calendar" : "Novo Calendário",
-    "Subscriptions" : "Subscrições",
+    "Name" : "Nome",
     "New Subscription" : "Nova Subscrição",
-    "Url" : "Url",
+    "WebCal-URL" : "Endereço-WebCal",
     "Edit event" : "Editar evento",
     "Delete Event" : "Eliminar Evento",
     "Save Event" : "Guardar Evento",
@@ -124,6 +130,7 @@ OC.L10N.register(
     "New calendar" : "Novo calendário",
     "Import scheduled" : "Importação agendada",
     "Settings" : "Configurações",
+    "Show week numbers" : "Mostrar o número das semanas",
     "Import calendar" : "Importar calendário",
     "No Calendars selected for import" : "Sem Calendários selecionados para importar",
     "Primary CalDAV address" : "Endereço principal CalDAV",
