@@ -13,6 +13,13 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Вы находитесь в неизвестном часовом поясе ({tz}), возвращаемся к UTC",
     "Please create a calendar first." : "Пожалуйста, создайте сначала календарь.",
     "New event" : "Новое событие",
+    "CalDAV address for clients" : "CalDAV адрес для клиентов",
+    "Error saving WebCal-calendar" : "Ошибка при сохранении календаря WebCal",
+    "WebDAV address for subscriptions" : "WebDAV адрес для подписок",
+    "EMail has been sent." : "E-mail был отправлен.",
+    "There was an issue while sending your EMail." : "Произошла ошибка при отправке вашего сообщения.",
+    "group" : "группа",
+    "Details" : "Подробно",
     "Attendees" : "Участники",
     "Reminders" : "Напоминания",
     "Repeating" : "Повторение",
@@ -67,6 +74,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} в момент окончания события",
     "{type} at {time}" : "{type} в {time}",
     "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
+    "Please enter a valid WebCal-URL" : "Пожалуйста, введите правильный адрес WebCal",
     "Title of the Event" : "Название события",
     "starts" : "начинается",
     "ends" : "заканчивается",
@@ -82,26 +90,33 @@ OC.L10N.register(
     "Event status" : "Статус события",
     "Visibility when sharing" : "Видимость при общем доступе",
     "Export" : "Экспорт",
+    "Hello," : "Привет,",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Из-за предшествующей ошибки, календарь в настоящее время не в состоянии обеспечить поддержку функции файлопровода.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Пожалуйста свяжитесь с администратором и попросите отключить опцию \"assep-pipeline.enabled\"",
     "Day" : "День",
     "Week" : "Неделя",
     "Month" : "Месяц",
     "Today" : "Сегодня",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Некоторые события в этом календаре испорчены. Пожалуйста проверьте консоль JS для дополнительной информации.",
-    "Share Calendar" : "Поделиться календарем",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Некоторые события в этом календаре испорчены. Пожалуйста проверьте консоль JS для получения дополнительной информации.",
+    "Share Calendar" : "Поделиться календарём",
     "Shared" : "Общий доступ",
     "More" : "Больше",
     "Edit" : "Редактировать",
     "Link" : "Ссылка",
+    "WebCal URL" : "Адрес WebCal",
     "Download" : "Скачать",
     "Share with users or groups" : "Общий доступ с пользователями или группами",
     "can edit" : "можно редактировать",
-    "group" : "группа",
+    "Share link" : "Поделиться ссылкой",
+    "Public access" : "Публичный доступ",
+    "Email link to person" : "Отправить ссылку по электронной почте",
+    "Send" : "Отправить",
     "New Calendar" : "Новый Календарь",
-    "Subscriptions" : "Подписки",
+    "Name" : "Название",
     "New Subscription" : "Новая подписка",
-    "Url" : "Url",
+    "WebCal-URL" : "Адрес WebCal",
+    "Go back" : "Назад",
+    "Go forward" : "Вперед",
     "Edit event" : "Редактировать событие",
     "Delete Event" : "Удалить событие",
     "Save Event" : "Сохранить событие",
@@ -130,6 +145,7 @@ OC.L10N.register(
     "Import scheduled" : "Импорт запланирован",
     "Settings" : "Настройки",
     "Skip simple event editor" : "Пропустить простой редактор события",
+    "Show week numbers" : "Показать номера недель",
     "Import calendar" : "Импорт календаря",
     "No Calendars selected for import" : "Календари для импорта не выбраны",
     "Primary CalDAV address" : "Основной адрес синхронизации CalDAV",
