@@ -13,12 +13,13 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Ste v neznámej časovej zóne ({tz}), používa sa UTC",
     "Please create a calendar first." : "Prosím, najskôr vytvorte kalendár",
     "New event" : "Nová udalosť",
+    "group" : "skupina",
     "Attendees" : "Účastníci",
     "Reminders" : "Pripomienky",
     "Repeating" : "Opakovanie",
-    "When shared show full event" : "Zobraziť úplnú udalosť, ak je zdieľaná",
-    "When shared show only busy" : "Zobraziť zaneprázdnený, ak je udalosť zdieľaná",
-    "When shared hide this event" : "Skryť udalosť, ak je zdieľaná",
+    "When shared show full event" : "Zobraziť úplnú udalosť, ak je sprístupnená",
+    "When shared show only busy" : "Zobraziť zaneprázdnený, ak je udalosť sprístupnená",
+    "When shared hide this event" : "Skryť udalosť, ak je sprístupnená",
     "Confirmed" : "Potvrdené",
     "Tentative" : "Neistý",
     "Cancelled" : "Zrušené",
@@ -63,7 +64,7 @@ OC.L10N.register(
     "{type} at the event's start" : "{type} pri začiatku udalosti",
     "{type} at the event's end" : "{type} pri skončení udalosti",
     "{type} at {time}" : "{type} o {time}",
-    "{calendar} shared by {owner}" : "{calendar} zdieľa {owner}",
+    "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
     "Title of the Event" : "Názov udalosti",
     "starts" : "začína",
     "ends" : "končí",
@@ -77,25 +78,23 @@ OC.L10N.register(
     "Location" : "Umiestnenie",
     "Description" : "Popis",
     "Event status" : "Stav udalosti",
-    "Visibility when sharing" : "Viditelnosť pri zdielaní",
+    "Visibility when sharing" : "Viditelnosť pri sprístupnení",
     "Export" : "Export",
     "Day" : "Deň",
     "Week" : "Týždeň",
     "Month" : "Mesiac",
     "Today" : "Dnes",
-    "Share Calendar" : "Zdielať kalendár",
-    "Shared" : "Zdieľané",
+    "Share Calendar" : "Sprístupniť kalendár",
+    "Shared" : "Sprístupnené",
     "More" : "Viac",
     "Edit" : "Upraviť",
     "Link" : "Odkaz",
     "Download" : "Sťahovanie",
     "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
     "can edit" : "môže upraviť",
-    "group" : "skupina",
     "New Calendar" : "Nový kalendár",
-    "Subscriptions" : "Odbery",
+    "Name" : "Názov",
     "New Subscription" : "Nový odber",
-    "Url" : "Url",
     "Edit event" : "Upraviť udalosť",
     "Delete Event" : "Zmazať udalosť",
     "Save Event" : "Uložiť udalosť",
