@@ -13,6 +13,8 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Ni mogoče določiti časovnega pasu ({tz}), zato bo prikazan čas UTC",
     "Please create a calendar first." : "Najprej je treba ustvariti koledar.",
     "New event" : "Nov dogodek",
+    "Error saving WebCal-calendar" : "Napaka shranjevanja koledarja WebCal",
+    "group" : "skupina",
     "Attendees" : "Udeleženci",
     "Reminders" : "Opomniki",
     "Repeating" : "Ponavljanje",
@@ -67,6 +69,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} ob koncu dogodka",
     "{type} at {time}" : "{type} ob {time}",
     "{calendar} shared by {owner}" : "{calendar} je objavila oseba {owner}",
+    "Please enter a valid WebCal-URL" : "Vpišite veljaven naslov URL WebCal",
     "Title of the Event" : "Naslov dogodka",
     "starts" : "začetek",
     "ends" : "konec",
@@ -94,14 +97,14 @@ OC.L10N.register(
     "More" : "Več",
     "Edit" : "Uredi",
     "Link" : "Povezava",
+    "WebCal URL" : "Naslov URL WebCal",
     "Download" : "Prejmi",
     "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
     "can edit" : "lahko ureja",
-    "group" : "skupina",
     "New Calendar" : "Nov koledar",
-    "Subscriptions" : "Naročila",
+    "Name" : "Ime",
     "New Subscription" : "Novo naročilo",
-    "Url" : "Naslov URL",
+    "WebCal-URL" : "WebCal-URL",
     "Edit event" : "Uredi dogodek",
     "Delete Event" : "Izbriši dogodek",
     "Save Event" : "Shrani dogodek",
@@ -130,6 +133,7 @@ OC.L10N.register(
     "Import scheduled" : "Uvoz urnika",
     "Settings" : "Nastavitve",
     "Skip simple event editor" : "Preskoči enostavni urejevalnik dogodkov",
+    "Show week numbers" : "Pokaži številke tednov",
     "Import calendar" : "Uvoz koledarja",
     "No Calendars selected for import" : "Ni navedenih koledarjev za uvoz",
     "Primary CalDAV address" : "Osnovni naslov CalDAV",
