@@ -13,6 +13,7 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Du är i en okänd tidszon ({tz}), faller tillbaka på UTC",
     "Please create a calendar first." : "Vänlligen skapa en kalender först.",
     "New event" : "Nytt event",
+    "group" : "Grupp",
     "Attendees" : "Deltagare",
     "Reminders" : "Påminnelser",
     "Repeating" : "Repetera",
@@ -92,11 +93,9 @@ OC.L10N.register(
     "Download" : "Ladda ned",
     "Share with users or groups" : "Dela med användare eller grupper",
     "can edit" : "kan redigera",
-    "group" : "Grupp",
     "New Calendar" : "Ny kalender",
-    "Subscriptions" : "Prenumerationer",
+    "Name" : "Namn",
     "New Subscription" : "Ny prenumeration",
-    "Url" : "Url",
     "Edit event" : "Redigera händelse",
     "Delete Event" : "Radera händelse",
     "Save Event" : "Spara händelse",
