@@ -13,6 +13,7 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "คุณอยู่ในเขตเวลาที่ไม่รู้จัก ({tz}), กำลงกลับไปสู่ UTC",
     "Please create a calendar first." : "กรุณาสร้างปฏิทินก่อน",
     "New event" : "เหตุการณ์ใหม่",
+    "group" : "กลุ่มผู้ใช้งาน",
     "Attendees" : "ผู้เข้าร่วมกิจกรรม",
     "Reminders" : "การแจ้งเตือน",
     "Repeating" : "ทำซ้ำ",
@@ -97,11 +98,9 @@ OC.L10N.register(
     "Download" : "ดาวน์โหลด",
     "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
     "can edit" : "สามารถแก้ไข",
-    "group" : "กลุ่มผู้ใช้งาน",
     "New Calendar" : "สร้างปฏิทินใหม่",
-    "Subscriptions" : "สมัครสมาชิก",
+    "Name" : "ชื่อ",
     "New Subscription" : "สมัครสมาชิกใหม่",
-    "Url" : "Url",
     "Edit event" : "แก้ไขกิจกรรม",
     "Delete Event" : "ลบเหตุการณ์",
     "Save Event" : "บันทึกเหตุการณ์",
@@ -129,6 +128,7 @@ OC.L10N.register(
     "New calendar" : "สร้างปฏิทินใหม่",
     "Import scheduled" : "นำเข้าตารางเวลาตามที่กำหนดไว้",
     "Settings" : "ตั้งค่า",
+    "Skip simple event editor" : "ข้ามการแก้ไขกิจกรรมอย่างง่าย",
     "Import calendar" : "นำเข้าปฏิทิน",
     "No Calendars selected for import" : "ไม่มีปฏิทินที่เลือกนำเข้า",
     "Primary CalDAV address" : "ที่อยู่ CalDAV หลัก",
