@@ -13,12 +13,15 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "您处于未知时区({tz}),请调整回UTC时间",
     "Please create a calendar first." : "请先创建一个新的日历。",
     "New event" : "新事件",
+    "Error saving WebCal-calendar" : "保存WebCal日历时出错",
+    "group" : "群组",
     "Attendees" : "参加者",
     "Reminders" : "提醒",
     "Repeating" : "重复",
     "When shared show full event" : "共享时显示完整事件",
     "When shared show only busy" : "共享时仅显示进行中的事件",
     "When shared hide this event" : "共享时隐藏本事件",
+    "Confirmed" : "已确认",
     "Cancelled" : "已取消",
     "Please add a title!" : "请添加一个标题。",
     "Please select a calendar!" : "请选择一个日历。",
@@ -65,6 +68,7 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} 事件结束时",
     "{type} at {time}" : "{type} {time}",
     "{calendar} shared by {owner}" : "{calendar} 由 {owner} 共享",
+    "Please enter a valid WebCal-URL" : "请输入有效的WebCal地址",
     "Title of the Event" : "事件标题",
     "starts" : "开始于",
     "ends" : "结束于",
@@ -77,6 +81,8 @@ OC.L10N.register(
     "Close" : "关闭",
     "Location" : "地点",
     "Description" : "描述",
+    "Event status" : "事件状态",
+    "Visibility when sharing" : "共享时是否可见",
     "Export" : "导出",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "由于上游的bug，日历目前无法提供资产管道功能的支持。",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "资产管道功能被禁用，请联系系统管理员。",
@@ -84,19 +90,20 @@ OC.L10N.register(
     "Week" : "星期",
     "Month" : "月",
     "Today" : "今天",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "日历中的某些事件已损坏。更多信息请在JS控制台中查看。",
     "Share Calendar" : "共享日历",
     "Shared" : "已共享",
     "More" : "更多",
     "Edit" : "编辑",
     "Link" : "链接",
+    "WebCal URL" : "WebCal地址",
     "Download" : "下载",
     "Share with users or groups" : "共享给其他组或者用户",
     "can edit" : "可编辑",
-    "group" : "群组",
     "New Calendar" : "新建日历",
-    "Subscriptions" : "订阅",
+    "Name" : "名称",
     "New Subscription" : "新的订阅",
-    "Url" : "URL",
+    "WebCal-URL" : "WebCal地址",
     "Edit event" : "编辑事件",
     "Delete Event" : "删除事件",
     "Save Event" : "保存事件",
@@ -112,8 +119,10 @@ OC.L10N.register(
     "from" : "从",
     "to" : "到",
     "This event's repeating rule is not supported yet." : "此事件的重复规则还没有被支持。",
+    "Reset repeating rule" : "重置重复规则",
     "Repeat every ..." : "重复",
     "end repeat ..." : "结束重复",
+    "times" : "次数",
     "Import Calendars" : "导入日历",
     "Import canceled" : "导入已取消",
     "Analyzing calendar" : "分析日历",
@@ -121,6 +130,8 @@ OC.L10N.register(
     "New calendar" : "新建日历",
     "Import scheduled" : "导入时间表",
     "Settings" : "设置",
+    "Skip simple event editor" : "跳过简单事件编辑器",
+    "Show week numbers" : "显示周次",
     "Import calendar" : "导入日历",
     "No Calendars selected for import" : "未选择要导入的日历",
     "Primary CalDAV address" : "主要的 CalDAV 地址",
