@@ -4,7 +4,7 @@
  *
  * @author Raghu Nayyar
  * @author Georg Ehrke
- * @copyright 2016 Raghu Nayyar <beingminimal@gmail.com>
+ * @copyright 2016 Raghu Nayyar <hey@raghunayyar.com>
  * @copyright 2016 Georg Ehrke <oc.list@georgehrke.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -21,6 +21,15 @@
  * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
+
+ /* OpenGraph */
+if($_['isPublic']) {
+	OCP\Util::addHeader('meta', ['property' => "og:title", 'content' => $theme->getName() . ' - ' . $theme->getSlogan()]);
+	OCP\Util::addHeader('meta', ['property' => "og:site_name", 'content' => $theme->getName()]);
+	OCP\Util::addHeader('meta', ['property' => "og:url", 'content' => $_['shareURL']]);
+	OCP\Util::addHeader('meta', ['property' => "og:type", 'content' => "object"]);
+	OCP\Util::addHeader('meta', ['property' => "og:image", 'content' => $_['previewImage']]);
+}
 $styles = [
 	'../js/vendor/fullcalendar/dist/fullcalendar',
 	'../js/vendor/jquery-timepicker/jquery.ui.timepicker',
@@ -34,13 +43,14 @@ foreach ($styles as $style) {
 $scripts = [
 	'vendor/jquery-timepicker/jquery.ui.timepicker',
 	'vendor/ical.js/build/ical',
-	'vendor/jstzdetect/jstz.min',
+	'vendor/jstzdetect/jstz',
 	'vendor/angular/angular',
-	'vendor/angular-bootstrap/ui-bootstrap.min',
-	'vendor/angular-bootstrap/ui-bootstrap-tpls.min',
+	'vendor/angular-bootstrap/ui-bootstrap',
+	'vendor/angular-bootstrap/ui-bootstrap-tpls',
 	'vendor/fullcalendar/dist/fullcalendar',
-	'vendor/fullcalendar/dist/lang-all',
+	'vendor/fullcalendar/dist/locale-all',
 	'vendor/davclient.js/lib/client',
+	'vendor/hsl_rgb_converter/converter',
 	'public/app'
 ];
 
@@ -53,11 +63,14 @@ foreach ($scripts as $script) {
 	<!-- The Left Calendar Navigation -->
 	<div id="app-navigation">
 
-		<div ng-controller="DatePickerController" id="datepickercontainer">
+		<div ng-controller="DatePickerController" id="datepickercontainer" ng-class="{active: visibility}">
 			<?php print_unescaped($this->inc('part.datepicker')); ?>
 			<?php print_unescaped($this->inc('part.buttonarea')); ?>
+			<div class="clear-both"></div>
 		</div>
-		<div ng-controller="CalendarListController" ng-cloak>
+
+		<?php if(!$_['isPublic']): ?>
+		<div ng-controller="CalendarListController" id="calendarlistcontainer" ng-cloak>
 			<div id="scrollable">
 				<?php print_unescaped($this->inc('part.createcalendar')); ?>
 				<?php print_unescaped($this->inc('part.calendarlist')); ?>
@@ -72,6 +85,11 @@ foreach ($scripts as $script) {
 				<?php print_unescaped($this->inc('part.settings')); ?>
 			</div>
 		</div>
+		<?php else: ?>
+		<div ng-controller="CalendarListController" id="publicinformationscontainer">
+			<?php print_unescaped($this->inc('part.publicinformations')); ?>
+		</div>
+		<?php endif; ?>
 	</div>
 
 	<!-- The Calendar on the right -->
@@ -80,7 +98,9 @@ foreach ($scripts as $script) {
 	</div>
 
 	<div id="popover-container"></div>
+	<?php if(!$_['isPublic']): ?>
 	<div id="importpopover-container"></div>
+	<?php endif; ?>
 
 	<script type="text/ng-template" id="eventspopovereditor.html">
 		<?php print_unescaped($this->inc('editor.popover')); ?>
@@ -90,7 +110,9 @@ foreach ($scripts as $script) {
 		<?php print_unescaped($this->inc('editor.sidebar')); ?>
 	</script>
 
+	<?php if(!$_['isPublic']): ?>
 	<script type="text/ng-template" id="import.html">
 		<?php print_unescaped($this->inc('part.import.dialog')); ?>
 	</script>
+	<?php endif; ?>
 </div>
